@@ -1,20 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "formatcomboboxtest.h"
-#include <QTest>
 #include "../widgets/formatcombobox.h"
+#include <QTest>
 
 FormatComboBoxTest::FormatComboBoxTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-FormatComboBoxTest::~FormatComboBoxTest()
-= default;
+FormatComboBoxTest::~FormatComboBoxTest() = default;
 
 void FormatComboBoxTest::shouldHaveDefaultValue()
 {
@@ -26,11 +25,11 @@ void FormatComboBoxTest::changeCurrentItem_data()
 {
     QTest::addColumn<int>("input");
     QTest::addColumn<int>("output");
-    QTest::newRow("first") <<  0 << 0;
-    QTest::newRow("second") <<  1 << 1;
-    QTest::newRow("third") <<  2 << 2;
-    QTest::newRow("fourth") <<  3 << 3;
-    QTest::newRow("invalid") <<  5 << 0;
+    QTest::newRow("first") << 0 << 0;
+    QTest::newRow("second") << 1 << 1;
+    QTest::newRow("third") << 2 << 2;
+    QTest::newRow("fourth") << 3 << 3;
+    QTest::newRow("invalid") << 5 << 0;
 }
 
 void FormatComboBoxTest::changeCurrentItem()
