@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,8 +16,7 @@ UnitComboBox::UnitComboBox(QWidget *parent)
     addItem(i18n("Years"), static_cast<int>(ArchiveMailInfo::ArchiveYears));
 }
 
-UnitComboBox::~UnitComboBox()
-= default;
+UnitComboBox::~UnitComboBox() = default;
 
 void UnitComboBox::setUnit(ArchiveMailInfo::ArchiveUnit unit)
 {
