@@ -6,6 +6,7 @@
 
 #pragma once
 
+#include <AkonadiCore/Item>
 #include <QObject>
 
 class MailMergeManager : public QObject
@@ -15,4 +16,10 @@ public:
     explicit MailMergeManager(QObject *parent = nullptr);
     ~MailMergeManager() override;
     Q_REQUIRED_RESULT QString printDebugInfo() const;
+    void load(bool state = false);
+    void stopAll();
+    Q_REQUIRED_RESULT bool itemRemoved(Akonadi::Item::Id id);
+
+Q_SIGNALS:
+    void needUpdateConfigDialogBox();
 };
