@@ -49,8 +49,8 @@ QString AccountsPage::helpAnchor() const
     return QStringLiteral("configure-accounts");
 }
 
-AccountsPage::AccountsPage(QWidget *parent)
-    : ConfigModuleWithTabs(parent)
+AccountsPage::AccountsPage(QWidget *parent, const QVariantList &args)
+    : ConfigModuleWithTabs(parent, args)
 {
     // Identity Tab:
     auto identityTab = new KMail::IdentityPage();
@@ -143,7 +143,7 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     glay->addWidget(mUndoSend, 4, 0);
     connect(mUndoSend, &QCheckBox::toggled, this, [this](bool state) {
         mUndoSendComboBox->setEnabled(state);
-        Q_EMIT slotEmitChanged();
+        slotEmitChanged();
     });
 
     mUndoSendComboBox = new UndoSendCombobox(this);
