@@ -42,7 +42,7 @@ void FolderArchiveManager::slotCollectionRemoved(const Akonadi::Collection &coll
 {
     KConfig config(FolderArchive::FolderArchiveUtil::configFileName());
     mFolderArchiveCache->clearCacheWithContainsCollection(collection.id());
-    for (FolderArchiveAccountInfo *info : qAsConst(mListAccountInfo)) {
+    for (FolderArchiveAccountInfo *info : std::as_const(mListAccountInfo)) {
         if (info->archiveTopLevel() == collection.id()) {
             info->setArchiveTopLevel(-1);
             KConfigGroup group = config.group(FolderArchive::FolderArchiveUtil::groupConfigPattern() + info->instanceName());
@@ -54,7 +54,7 @@ void FolderArchiveManager::slotCollectionRemoved(const Akonadi::Collection &coll
 
 FolderArchiveAccountInfo *FolderArchiveManager::infoFromInstanceName(const QString &instanceName) const
 {
-    for (FolderArchiveAccountInfo *info : qAsConst(mListAccountInfo)) {
+    for (FolderArchiveAccountInfo *info : std::as_const(mListAccountInfo)) {
         if (info->instanceName() == instanceName) {
             return info;
         }
@@ -124,7 +124,7 @@ void FolderArchiveManager::setArchiveItems(const Akonadi::Item::List &items, con
 void FolderArchiveManager::slotInstanceRemoved(const Akonadi::AgentInstance &instance)
 {
     const QString instanceName = instance.name();
-    for (FolderArchiveAccountInfo *info : qAsConst(mListAccountInfo)) {
+    for (FolderArchiveAccountInfo *info : std::as_const(mListAccountInfo)) {
         if (info->instanceName() == instanceName) {
             mListAccountInfo.removeAll(info);
             removeInfo(instanceName);
